---
title: Complex Numbers
---

Complex numbers
===============

Complex numbers are numbers of the form $$z = a + b {\rm i}.$$ Here
$\rm i$ is the square root of -1: $${\rm i} = \sqrt{-1},$$ or,
equivalently: $${\rm i}^2 = -1.$$

Usual operations for numbers have their natural extension for complex
numbers as we shall see below.

Some definitions:

-   For a complex number $z = a + b {{\rm i}}$, $a$ is called the *real
    part*, and $b$ the *imaginary part*.

-   The *complex conjugate* $z^*$ of $z = a + b {{\rm i}}$ is defined as
    $$z^* = a - b{{\rm i}},$$ i.e., taking the complex conjugate means
    flipping the sign of the imaginary part.

Addition
--------

For two complex numbers, $z_1 = a_1 + b_1 {{\rm i}}$ and
$z_2 = a_2 + b_2 {{\rm i}}$, the sum $w = z_1 + z_2$ is given as
$$w = w_1 + w_2 {{\rm i}}= (a_1 + a_2) + (b_1 + b_2) {{\rm i}}$$ where
the parentheses in the rightmost expression have been added to group the
real and the imaginary part. A consequence of this definition is that
the sum of a complex number and its complex conjugate is real:
$$z + z^* = a + b {{\rm i}}+ a - b {{\rm i}}= 2a,$$ i.e., this results
in twice the real part of $z$. Similarly, subtracting $z^*$ from $z$
yields $$z - z^* = a + b {{\rm i}} - a + b {{\rm i}}= 2b{\rm i},$$ i.e.,
twice the imaginary part of $z$ (times $\rm i$).

Multiplication
--------------

For the same two complex numbers $z_1$ and $z_2$ as above, their product
is calculated as
$$w = z_1 z_2 = (a_1 + b_1 {{\rm i}}) (a_2 + b_2 {{\rm i}}) = (a_1 a_2 - b_1 b_2) + (a_1 b_2 + a_2 b_1) {{\rm i}},$$
where the parentheses have again be used to indicate the real and
imaginary parts.

A consequence of this definition is that the product of a complex number
$z = a + b {{\rm i}}$ with its conjugate is real:
$$z z^* = (a+b{{\rm i}})(a-b{{\rm i}}) = a^2 + b^2.$$ The square root of
this number is the *norm* $|z|$ of $z$:
$$|z| = \sqrt{z z^*} = \sqrt{a^2 + b^2}.$$

Division
--------

The quotient $z_1/z_2$ of two complex numbers $z_1$ and $z_2$ as above,
can be evaluated by multiplying the numerator and denominator by the
complex conjugate of $z_2$:
$$\frac{z_1}{z_2} = \frac{z_1 z_2^*}{z_2 z_2^*} = \frac{(a_1 a_2 + b_1 b_2) + (-a_1 b_2 + a_2 b_1) {{\rm i}}}{a_2^2 + b_2^2}.$$
Check this!

The complex plane
=================

Complex numbers can be rendered on a two-dimensional (2D) plane, the
*complex plane*. This plane is spanned by two unit vectors, one
horizontal, which represents the real number 1, whereas the vertical
unit vector represents ${\rm i}$.

![image](figures/complex_numbers_5_0.svg)

Note that the norm of $z$ is the length of this vector.

Addition in the complex plane
-----------------------------

Adding two numbers in the complex plane corresponds to adding the
horizontal and vertical components:

![image](figures/complex_numbers_8_0.svg)

We see that the sum is found as the diagonal of a parallelogram spanned
by the two numbers.

Argument and Norm
-----------------

A complex number can be represented by two real numbers, $a$ and $b$
which represent the real and imaginary part of the complex number. An
alternative representation is a *vector* in the complex plane, whose
horizontal component is the real, and vertical component the imaginary
part. However, it is also possible to characterize that vector by its
*length* and *direction*, where the latter can be represented by the
angle the vector makes with the horizontal axis:

![image](figures/complex_numbers_10_0.svg)

The angle with the horizontal axis is denoted by $\varphi$, just as in
the case of polar coordinates. In the context of complex numbers, this
angle is denoted as the *argument*. We have:

> A complex number can be represented either by its real and imaginary
> part, corresponding to the Cartesian coordinates in the complex plane,
> or by its *norm* and its *argument*, corresponding to polar
> coordinates. The norm is the length of the vector, and the argument is
> the angle it makes with the horizontal axis.

From our previous discussion on polar coordinates we can conclude that
for a complex number $z = a + b {\rm i}$, its real and imaginary parts
can be expressed as $$a = |z| \cos\varphi$$ $$b = |z| \sin\varphi$$ The
inverse equations are $$|z| = \sqrt{a^2 + b^2}$$
$$\varphi = \arctan(b/a)$$ for $a>0$. In general:
$$\varphi = \begin{cases} \arctan(b/a) &{\rm for ~} a>0; \\
 \pi + \arctan(b/a) & {\rm for ~} a<0 {\rm ~ and ~} b>0;\\
 -\pi + \arctan(b/a) &{\rm ~ for ~} a<0 {\rm ~ and ~} b<0.
 \end{cases}$$

Complex functions
-----------------

A complex function $f$ maps any complex number $z$ onto another complex
number $f(z)$. Just as with real functions, we can define the derivative
of a complex function:
$$\frac{df(z)}{dz} = \lim_{dz \rightarrow 0} \frac{f(z+dz) - f(z)}{dz}.$$
It is useful to contemplate this expression for some time. The number
$dz$ in this expression is a *complex* number with vanishingly small
norm. However, its *direction* (i.e. its *argument*) is not specified. A
complex function is called *differentiable* only if the limit exists and
gives one and the same number, irrespective of the direction of $dz$.

Let’s see whether we can find a condition for this to happen. We assume
that the function $f$ is continuous. Note that, as $f$ is complex, it
can be written as a real plus an imaginary part:
$$f(z) = u(z) + {\rm i} v(z).$$ For $z=x + \rm i y$, we can write the
two functions $u$ and $v$ in terms of $x$ and $y$. Let us assume that
the two partial derivatives of these functions with respect to $x$ and
$y$ exist.

Calculating the partial derivatives of $f$ with respect to $x$ and $y$
yields:
$$\frac{\partial f(z)}{\partial x} = \lim_{dx \rightarrow 0} \frac{f(z+dx) - f(z)}{dx} = \frac{\partial u}{\partial x} + {\rm i} \frac{\partial v}{\partial x},$$
and
$$\frac{\partial f(z)}{\partial y} = \lim_{dy \rightarrow 0} \frac{f(z+{\rm i} dy) - f(z)}{dy} = \frac{\partial u}{\partial y} + {\rm i} \frac{\partial v}{\partial y}.$$
Unlike $df/dz$, these derivatives are always defined. In terms of these
two partial derivatives, we can find the derivative with respect to any
direction using first-order Taylor expansions. Taking
$dz = d x + {\rm i} dy$, we have
$$f(z + dz) = u(x+dx, y+dy) + {\rm i} v(x+dx, y+dy) = u(x,y) + {\rm i} v(x,y) + dx \frac{\partial u}{\partial x} + dy \frac{\partial u}{\partial y} + 
{\rm i} \left[ dx \frac{\partial v}{\partial x} + dy \frac{\partial  v}{\partial y} \right].$$
Collecting the terms proportional to $dx$ and $dy$ respectively we
obtain:
$$f(z + dz ) = f(z) + \left( \frac{\partial u}{\partial x} + {\rm i} \frac{\partial v}{\partial x} \right) dx +
\left( \frac{\partial u}{\partial y} + {\rm i} \frac{\partial v}{\partial y} \right) dy.$$
Let’s write
$$f(z + dz ) - f(z) = \left( \frac{\partial u}{\partial x} + {\rm i}\frac{\partial v}{\partial x} \right) dx +
{\rm i} \left( -{\rm i} \frac{\partial u}{\partial y} + \frac{\partial v}{\partial y} \right) dy.$$
If the derivative $df/dz$ exists, the right hand side divided by $dz$
should be independent of $dz=dx + {\rm i} dy$! Thus, $f(z)$ is
differentiable only when
$$\frac{\partial u}{\partial x} + {\rm i} \frac{\partial v}{\partial x} = -{\rm i} \frac{\partial u}{\partial y} + \frac{\partial v}{\partial y}.$$
Equating the real and imaginary parts of the left and right hand side we
obtain the *Cauchy Riemann* differential equations:
$$\frac{\partial u}{\partial x} = \frac{\partial v}{\partial y} {~~~ \rm and ~~~ } \frac{\partial v}{\partial x} = - 
\frac{\partial u}{\partial y}.$$ The derivative is then given as
$$\frac{df}{dz} = \frac{\partial u}{\partial x} + {\rm i} \frac{\partial v}{\partial x}.$$
A complex function whose real and imaginary part ($u$ and $v$) obey the
Cauchy-Riemann differential equations in a point $z$, is complex
differentiable at the point $z$.

Note that differentiability is a property which not only pertains to a
function, but also to a point.

It can be shown that a complex function which is differentiable in $z$,
is infinitely differentiable. Such a function is called *analytic* in
the point $z$. An analytic function can be expanded as an inifinite
series near any point where the function is analytic. Here, “near any”
point indicates that the series converges and coincides with $f$ only on
a *circle* in the complex plane. The radius of that circle is limited to
the distance of $z$ to the nearest point $w$ where the function is not
analytic. This distance is called the *convergence radius*.

Recall that the Taylor series around a complex point $a$ has the form
$$f(z) = \sum_{j=0}^\infty d_j (z-a)^j,$$ where
$$d_j = \frac{1}{j!} f^{(j)} (a).$$ Here, $f^{(j)}(a)$ denotes the
$j$-th derivative of the function $f$ in the point $a$.

The complex exponential function
--------------------------------

The exponential function $f(z) = \exp(z) = e^z$ is defined as:
$$\exp(z) = e^{x} \left( \cos y + {\rm i} \sin y\right).$$

**Exercise** Check that this function obeys
$$\exp(z_1) \exp(z_2) = \exp(z_1 + z_2).$$ You need sum- and difference
formulas of cosine and sine.

**Exercise** Check that $\exp(z)$ obeys the Cauchy-Riemann equations and
that the derivative is the exponential function itself:
$$\frac{d \exp(z)}{dz} = \exp(z).$$ Note that, for any complex number
$z$, we can write $$z = |z| e^{\rm i \varphi},$$ where
$\varphi = \text{arg}(z)$.

In *real calculus*, the logarithmic function is the inverse of the
exponential function. Similarly, we want the complex logarithm to be the
inverse of the complex exponential function. Let’s write
$w = \exp(z) = e^x(\cos y + \rm i \sin y)$. We know then that
$\log(w) = z = x + \rm i y$. Realising that the norm of
$\cos y + \rm i \sin y$ is 1 (check this!), we see that
$\left|w\right| = e^x$. Therefore, the real part of $\log w$ is the real
logarithm of $|w|$.

The imaginary part of the $\log w$ should be $y$. Now, $y$ is the
*argument* of $w$. All in all, we therefore see that
$$\log w = \log|w| + \rm i \arg(w).$$

The complex exponential is used *extremely often*. It occurs in Fourier
transforms and is very convenient for doing calculations involving
cosines and sines.

Let us show some tricks where the simple properties of the exponential
function helps in re-deriving trigonometric identities.

1.  Take $|z_1| = |z_2| = 1$, and $\arg{(z_1)} = \varphi_1$ and
    $\arg{(z_2)} = \varphi_2$. Then it is easy to see that
    $z_i = \exp({\rm i} \varphi_i)$, $i=1, 2$. Then:
    $$z_1 z_2 = \exp[{\rm i} (\varphi_1 + \varphi_2)].$$ The left hand
    side can be written as
    $$z_1 z_2 = \left[ \cos(\varphi_1) + {\rm i} \sin(\varphi_1) \right] \left[ \cos(\varphi_2) + {\rm i} \sin(\varphi_2) \right] = \cos\varphi_1 \cos\varphi_2 - \sin\varphi_1 \sin\varphi_2 + {\rm i} \left( \cos\varphi_1 \sin\varphi_2 + 
    \sin\varphi_1 \cos\varphi_2 \right).$$ On the other hand, the right
    hand side can be written as
    $$\exp[{\rm i} (\varphi_1 + \varphi_2)] = \cos(\varphi_1 + \varphi_2) + {\rm i} \sin(\varphi_1 + \varphi_2).$$
    Comparing the two expressions, equating their real and imaginary
    parts, we find
    $$\cos(\varphi_1 + \varphi_2) = \cos\varphi_1 \cos\varphi_2 - \sin\varphi_1 \sin\varphi_2;$$
    $$\sin(\varphi_1 + \varphi_2) = \cos\varphi_1 \sin\varphi_2 + 
    \sin\varphi_1 \cos\varphi_2.$$ Note that we used the resulting
    formulas already in order to derive the properties of the
    exponential function. The point is that you can use the properties
    of the complex exponential to quickly find the form of gonometric
    formulas which you easily forget.

2.  As a final example, consider what we can learn from the derivative
    of the exponential function:
    $$\frac{d}{d\varphi} \exp({\rm i} \varphi) = {\rm i} \exp({\rm i} \varphi) .$$
    Writing out the exponential in terms of cosine and sine, we see that
    $$\cos'\varphi + {\rm i} \sin'\varphi = {\rm i} \cos\varphi - \sin\varphi.$$
    where the prime $'$ denotes the derivative as usual. Equating real
    and imaginary parts leads to $$\cos'\varphi = - \sin\varphi;$$
    $$\sin'\varphi = \cos\varphi.$$

Hyperbolic functions
--------------------

From
$e^{\rm i \varphi} = \left( \cos\varphi + {\rm i} \sin\varphi\right)$,
it immediately follows that
$$\cos\varphi = \frac{e^{{\rm i} \varphi} + e^{-{\rm i} \varphi}}{2}.$$
and
$$\sin\varphi = \frac{e^{{\rm i} \varphi} - e^{-{\rm i} \varphi}}{2{\rm i}}.$$
It is then tempting to generalise these functions for imaginary angles.
These functions are known as hyperbolic functions. They are are called
the hyperbolic cosine and hyperbolic sine functions and they are denoted
as $\sinh$ and $\cosh$: $$\cosh(x) = \frac{e^x + e^{-x}}{2};$$
$$\sinh(x) = \frac{e^x - e^{-x}}{2}.$$ From these definitions the
following properties can easily be derived.

1.  Derivatives $$\frac{d\cosh(x)}{dx} = \sinh(x);$$
    $$\frac{d\sinh(x)}{dx} = \cosh(x).$$

2.  $$\cosh^2(x) - \sinh^2(x) = 1.$$

3.  ‘Double angle’ formulas: $$\cosh(2x) = \cosh^2(x) + \sinh^2(x);$$
    $$\sinh(2x) = 2\cosh(x) \sinh(x).$$

It may seem that these function are rather exotic; however they occur in
everyday life: the shapes of power lines and of soap films can be
described by hyperbolic cosines and sines!

Finally, the hyperbolic tangent is defined as
$$\tanh(x) = \frac{\sinh(x)}{\cosh(x)}.$$ Its derivative is given as
$$\tanh'(x) = 1 + \frac{\sinh^2 x}{\cosh^2 (x)} = - \frac{1}{\cosh^2(x)}.$$

Summary
=======

-   A complex number $z$ has the form $$z = a + b \rm i$$ where $a$ and
    $b$ are both real, and $\rm i^2 = 1$. The real number $a$ is called
    the *real part* of $z$ and $b$ is the *imaginary part*. Two complex
    numbers can be added, subtracted and multiplied straightforwardly.
    The quotient of two complex numbers $z_1=a_1 + \rm i b_1$ and
    $z_2=a_2 + \rm i b_2$ is
    $$\frac{z_1}{z_2} = \frac{z_1 z_2^*}{z_2 z_2^*} = \frac{(a_1 a_2 + b_1 b_2) + (-a_1 b_2 + a_2 b_1) {{\rm i}}}{a_2^2 + b_2^2}.$$

-   Complex numbers can also be characterised by their *norm*
    $|z|=\sqrt{a^2+b^2}$ and *argument* $\phi$. These coordinates
    correspond to polar coordinates in the complex plane. For a complex
    number $z = a + b {\rm i}$, its real and imaginary parts can be
    expressed as $$a = |z| \cos\varphi$$ $$b = |z| \sin\varphi$$ The
    inverse equations are $$|z| = \sqrt{a^2 + b^2}$$
    $$\varphi = \begin{cases} \arctan(b/a) &{\rm for ~} a>0; \\
     \pi + \arctan(b/a) & {\rm for ~} a<0 {\rm ~ and ~} b>0;\\
     -\pi + \arctan(b/a) &{\rm ~ for ~} a<0 {\rm ~ and ~} b<0.
     \end{cases}$$

-   The derivative of a complex function $f(z)$ is defined as
    $$\frac{df(z)}{dz} = \lim_{dz \rightarrow 0} \frac{f(z+dz) - f(z)}{dz}.$$
    The right hand side depends on the direction of $dz$ in the complex
    plane. The function is said to be *differentiable* if the right hand
    side gives a unique value. This is the case when the real part $u$
    and imaginary part $v$ of the function $f$ satisfy the
    *Cauchy–Riemann* equations:
    $$\frac{\partial u}{\partial x} = \frac{\partial v}{\partial y} {~~~ \rm and ~~~ } \frac{\partial v}{\partial x} = - 
    \frac{\partial u}{\partial y}.$$ A function which is differentiable,
    is differentiable infinitely often. Such a function can be expanded
    as a Taylor series:
    $$f(z) = \sum_{j=0}^\infty \frac{1}{j!} f^{(j)} (a) (z-a)^j,$$ where
    $f^{(j)} (a)$ is the $j$-th derivative of the function $f$ in $a$.

-   Examples of differentiable functions:

    -   The complex exponential:
        $$e^z = e^{x} \left( \cos y + \rm i \sin y\right).$$

    -   The complex logarithm: $$\log(z) = \log|z| +\rm i \arg(z).$$

    -   The complex sine and cosine functions are defined as
        $$\sin(z) = \frac{e^{\rm i z} - e^{-\rm i z}}{2\rm i}; \phantom{xxx} \cos(z) = \frac{e^{\rm i z} + e^{-\rm i z}}{2}.$$
        The complex tangent is defined as $\tan(z) = \sin(z)/\cos(z)$.

    -   Hyperbolic functions are defined as:
        $$\sinh(z) = \frac{e^{z} - e^{-z}}{2}; \phantom{xxx} \cosh(z) = \frac{e^{z} + e^{-z}}{2}.$$


Problems
========

1.  [:grinning:]  Given $a=1+2\rm i$ and $b=4-2\rm i$, draw in the
    complex plane the numbers $a+b$, $a-b$, $ab$, $a/b$, $e^a$ and
    $\ln(a)$.

2.  [:grinning:] Evaluate (i) $\rm i^{1/4}$, (ii)
    $\left(-1+\rm i \sqrt{3}\right)^{1/2}$, (iii) $\exp(2\rm i^3)$.

3.  [:grinning:] Evaluate $$\left| \frac{a+b\rm i}{a-b\rm i} \right|$$
    for real $a$ and $b$.

4.  [:grinning:] Show that $\cos x = \cosh(\rm i x)$ and
    $\cos(\rm i x) = \cosh x$. Derive similar relations for $\sinh$ and
    $\sin$.

    Show that $\cosh^2 x - \sinh^2 x = 1$.

    Also show that $\cosh x$ is a solution to the differential equation
    $$y'' = \sqrt{1 + y'^2}.$$

5.  [:grinning:] Calculate the real part of
    $\int_0^\infty e^{-\gamma t  +\rm i \omega t} dt$ ($\omega$ and
    $\gamma$ are real; $\gamma$ is positive).

6.  [:grinning:] Is the function $f(z) = |z| = \sqrt{x^2 + y^2}$
    analytic on the complex plane or not? If not, where is the function
    not analytic?

7.  [:grinning:] Show that the Cauchy-Riemann equations imply that the
    real and imaginary part of a differentiable complex function both
    represent solutions to the Laplace equation, i.e.
    $$\frac{\partial^2 u}{\partial x^2} + \frac{\partial^2 u}{\partial y^2} = 0,$$
    for the real part $u$ of the function, and similarly for the
    imaginary part $v$.

8.  [:sweat:] Show that the set of points $z$ obeying
    $$| z - \rm i a| = \lambda |z + \rm i a|,$$ with $a$ and $\lambda$
    real, form a circle with radius $2|\lambda/(1-\lambda^2) a|$
    centered on the point $\rm i a (1+\lambda^2)/(1-\lambda^2)$,
    provided $\lambda \neq 1$. What is the set like for $\lambda = 1$?

9.  [:smirk:] In two dimensions, the Coulomb potential is
    proportional to $\log |r|$. Viewing the 2D space as a complex plane,
    this is $\log |z|$. Consider a system consisting of charges $q_i$
    placed at ‘positions’ $z_i$, all close to the origin. The point $z$
    is however located far away from the origin. Use the Taylor
    expansions of the terms $\ln(z-z_i)$ at $z$ with respect to the
    $z_i$ to write the potential at $z$ as
    $$U(z) = \sum_i q_i\ln(z-z_i) = a_0 \ln z - \sum_{k=1}^M \frac{a_k}{z^k} + {\mathcal O} \left( \frac{R}{z} \right)^{M+1}$$
    where
    $$a_0 = \sum_i q_i {\rm ~~ and ~~} a_k = \sum_{i=1}^{N_c} \frac{q_i z_i^k}{k}, k\geq 1.$$
    (Note that, for the potential, the real part of the right hand side
    is to be taken.)

    This is called a *multipole expansion*. A similar expansion exist in
    three dimensions.

10. [:smirk:] In this problem, we consider the function $1/z$ close
    to the real axis: $z=x-\rm i \epsilon$ where $\epsilon$ is small.
    Show that the imaginary part of this function approaches $\pi$ times
    the Dirac delta-function $\delta(x)$ for $\epsilon\rightarrow 0$. Do
    this by showing that the integral over that function is $\pi$ and
    that, when multiplied by a function $f(x)$, the result only depends
    on $f(0)$.
